@@ -16,8 +16,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef EV_VERSION_H
-#define EV_VERSION_H
+#pragma once
 
 /**
  * SECTION:ev-version
@@ -33,7 +32,7 @@
  * (e.g. in version 3.1.4 this is 3).
  */
 
-#define EV_MAJOR_VERSION (41)
+#define EV_MAJOR_VERSION (44)
 
 /**
  * EV_MINOR_VERSION:
@@ -41,7 +40,7 @@
  * The minor version number of the EV library
  * (e.g. in version 3.1.4 this is 1).
  */
-#define EV_MINOR_VERSION (3)
+#define EV_MINOR_VERSION (1)
 
 /**
  * EV_CHECK_VERSION:
@@ -55,5 +54,3 @@
 #define EV_CHECK_VERSION(major,minor) \
   (EV_MAJOR_VERSION > (major) || \
    (EV_MAJOR_VERSION == (major) && EV_MINOR_VERSION > (minor))
-
-#endif /* #ifndef EV_VERSION_H */
